from .tags import (  # noqa: F401
    # Core types
    BaseTag,
    Class,
    Attr,
    Children,
    Fragment,
    # Escape hatch
    DangerousHtml,
    # Wrappers
    Area,
    Base,
    Br,
    Col,
    Embed,
    Hr,
    Img,
    Input,
    Link,
    Meta,
    Param,
    Source,
    Track,
    Wbr,
    A,
    Abbr,
    Address,
    Article,
    Aside,
    Audio,
    B,
    Bdi,
    Bdo,
    Blockquote,
    Body,
    Button,
    Canvas,
    Caption,
    Cite,
    Code,
    Colgroup,
    Command,
    Datalist,
    Dd,
    Del,
    Details,
    Dfn,
    Div,
    Dl,
    Dt,
    Em,
    Fieldset,
    Figcaption,
    Figure,
    Footer,
    Form,
    H1,
    H2,
    H3,
    H4,
    H5,
    H6,
    Head,
    Header,
    Hgroup,
    Html,
    I,
    Iframe,
    Ins,
    Kbd,
    Keygen,
    Label,
    Legend,
    Li,
    Map,
    Mark,
    Menu,
    Meter,
    Nav,
    Noscript,
    Object,
    Ol,
    Optgroup,
    Option,
    Output,
    P,
    Pre,
    Progress,
    Q,
    Rp,
    Rt,
    Ruby,
    S,
    Samp,
    Script,
    Section,
    Select,
    Small,
    Span,
    Strong,
    Style,
    Sub,
    Summary,
    Sup,
    Table,
    Tbody,
    Td,
    Textarea,
    Tfoot,
    Th,
    Thead,
    Time,
    Title,
    Tr,
    Ul,
    Var,
    Video,
)
